@@ -1,20 +1,17 @@
+mod handler;
 mod interceptor;
 mod internal;
-mod receipt_awaiter;
 
 use crate::client::internal::InternalClient;
 use crate::protocol::frame::{Abort, Ack, Begin, Commit, Nack, Send, Subscribe};
-use crate::protocol::{Frame, ServerCommand, StompMessage};
+use crate::protocol::{Frame, ServerCommand};
 use std::error::Error;
 use std::fmt::{Display, Formatter};
 use std::sync::Arc;
-use tokio::sync::mpsc::{Receiver, Sender};
+use tokio::sync::mpsc::Sender;
 use uuid::Uuid;
 
 type ReceiptId = String;
-type SubscriberId = String;
-type ServerStompSender = Sender<StompMessage<ServerCommand>>;
-type ServerStompReceiver = Receiver<StompMessage<ServerCommand>>;
 
 pub struct Transaction {
     transaction_id: String,
@@ -154,3 +151,25 @@ impl Client {
         })
     }
 }
+
+impl Frame<ServerCommand> {
+    pub fn ack(&self) -> Option<Ack> {
+        if let ServerCommand::Message = self.command {
+            if let Some(ack) = self.headers.get("ack") {
+                return Some(Ack::new(ack));
+            }
+        }
+
+        None
+    }
+
+    pub fn nack(&self) -> Option<Nack> {
+        if let ServerCommand::Message = self.command {
+            if let Some(ack) = self.headers.get("ack") {
+                return Some(Nack::new(ack));
+            }
+        }
+
+        None
+    }
+}
